@@ -15,8 +15,8 @@ use feature 'lexical_subs';
 no warnings "experimental::lexical_subs";
 
 package  Data::Dumper::Interp;
-our $VERSION = '5.023'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-05-29'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '5.024'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-06-02'; # DATE from Dist::Zilla::Plugin::OurDate
 
 package  
   # newline so Dist::Zilla::Plugin::PkgVersion won't add $VERSION
@@ -1810,7 +1810,7 @@ The avilable options are:
 
 Printable ("graphic")
 characters are shown as themselves rather than hex escapes, and
-'\n', '\t', etc. are shown for common ASCII control codes.
+'\n', '\t', etc. are shown for ASCII control codes.
 
 =item "controlpics"
 
